@@ -22,6 +22,6 @@ fn main() {
   if std::env::var("CARGO_FEATURE_PARSING_TABLES").is_ok() {
     // generate new LALR parsing tables for FEEL grammar
     // when executed with --features=parsing-tables
-    lalr_rust_tables();
+    lalr_rust_tables("./src/lalr.rs");
   }
 }
