@@ -604,6 +604,7 @@ impl<'lexer> Lexer<'lexer> {
         _ => {}
       }
     }
+
     // now the `parts` vector contains all parts of the longest possible name,
     // now must be decides what kind of name it is, by checking the parsing scope
 
@@ -666,11 +667,22 @@ impl<'lexer> Lexer<'lexer> {
     }
 
     // ------------------------------------------------------------------------
-    // tweak with date and time literals
+    // tweak with "date and time" and "duration" literals
+    // when these names are encountered then treat them as names of
+    // temporal functions
     // ------------------------------------------------------------------------
-    if matches!(name.to_string().as_str(), "date" | "date and time" | "time" | "duration") {
+    let name_str = name.to_string();
+    if matches!(name_str.as_str(), "date and time" | "duration") {
       return Ok((TokenType::NameDateTime, TokenValue::NameDateTime(name)));
     }
+    if matches!(name_str.as_str(), "date" | "time") {
+      return if self.is_next_character(&[':'], 0) {
+        // when colon is after these names, than treat them as named parameters
+        Ok((TokenType::Name, TokenValue::Name(name)))
+      } else {
+        Ok((TokenType::NameDateTime, TokenValue::NameDateTime(name)))
+      };
+    }
 
     // by default return the name as it appears on input
     Ok((TokenType::Name, TokenValue::Name(name)))
