@@ -102,6 +102,8 @@ macro_rules! trace_action {
 pub struct Parser<'parser> {
   /// Parsing scope.
   scope: &'parser Scope,
+  /// Parsed input.
+  input: &'parser str,
   /// Flag indicating whether the tracing messages should be printed to standard output.
   yy_trace: bool,
   /// The FEEL [Lexer] used by this FEEL [Parser] as an input token stream.
@@ -128,10 +130,11 @@ pub struct Parser<'parser> {
 
 impl<'parser> Parser<'parser> {
   /// Creates a new parser.
-  pub fn new(scope: &'parser Scope, start_token_type: TokenType, input: &str, trace: bool) -> Self {
+  pub fn new(scope: &'parser Scope, start_token_type: TokenType, input: &'parser str, trace: bool) -> Self {
     let lexer = Lexer::new(scope, start_token_type, input);
     Self {
       scope,
+      input,
       yy_trace: trace,
       yy_lexer: lexer,
       yy_char: TokenType::YyEmpty as i16,
@@ -270,11 +273,11 @@ impl<'parser> Parser<'parser> {
         Action::Error => {
           trace!(self, "\nERROR");
           self.yy_token = SymbolKind::YyError as i16;
-          return Err(syntax_error());
+          return Err(syntax_error(self.input));
         }
         Action::Error1 => {
           trace!(self, "\nERROR 1");
-          return Err(syntax_error());
+          return Err(syntax_error(self.input));
         }
         Action::Accept => {
           trace!(self, "\n**********");
@@ -1227,7 +1230,7 @@ mod errors {
   enum ParserError {
     NotAName(String),
     InvalidParseResult,
-    SyntaxError,
+    SyntaxError(String),
     PopError,
   }
 
@@ -1247,8 +1250,8 @@ mod errors {
         ParserError::InvalidParseResult => {
           write!(f, "invalid parse result, expected non empty AST node as a result when parser accepts input")
         }
-        ParserError::SyntaxError => {
-          write!(f, "syntax error")
+        ParserError::SyntaxError(input) => {
+          write!(f, "syntax error: {}", input)
         }
         ParserError::PopError => {
           write!(f, "pop error")
@@ -1268,8 +1271,8 @@ mod errors {
   }
 
   ///
-  pub fn syntax_error() -> DmntkError {
-    ParserError::SyntaxError.into()
+  pub fn syntax_error(input: &str) -> DmntkError {
+    ParserError::SyntaxError(input.to_string()).into()
   }
 
   ///
