@@ -14,23 +14,25 @@
  * SOFTWARE.
  */
 
-use super::{accept, empty_scope};
+use super::accept;
 use crate::lalr::TokenType::StartTextualExpression;
+use dmntk_feel::{scope, Scope};
 
 #[test]
 fn date_1() {
-  let scope = &mut empty_scope();
+  let scope = scope!();
   accept(
-    scope,
+    &scope,
     StartTextualExpression,
     r#"date("2012-12-25")"#,
     r#"
-        FunctionInvocation
-          Name
-            `date`
-          PositionalParameters
-            String `2012-12-25`
-      "#,
+       FunctionInvocation
+       ├─ Name
+       │  └─ `date`
+       └─ PositionalParameters
+          └─ String
+             └─ `2012-12-25`
+    "#,
     false,
   );
 }
