@@ -55,6 +55,8 @@ mod range;
 mod simple_positive_unary_test;
 mod some_expression;
 mod subtraction;
+mod temporal_date;
+mod temporal_date_time;
 mod textual_expressions;
 mod unary_tests;
 
